.. image:: https://travis-ci.org/ambitioninc/django-entity-event.png
   :target: https://travis-ci.org/ambitioninc/django-entity-event

.. image:: https://pypip.in/v/django-entity-event/badge.png
    :target: https://crate.io/packages/django-entity-event/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/django-entity-event/badge.png
    :target: https://crate.io/packages/django-entity-event/
    :alt: Number of PyPI downloads


Django Entity Event
===================

Django Entity Event is a great way to collect events that your users
care about into a unified location. The parts of your code base that
create these events are probably totally separate from the parts that
display them, which are also separate from the parts that manage
subscriptions to notifications. Django Entity Event makes separating
these concerns as simple as possible, and provides convenient
abstractions at each of these levels.

Installation
------------
To install the latest release, type::

    pip install django-entity-event

To install the latest code directly from source, type::

    pip install git+git://github.com/ambitioninc/django-entity-event.git

Documentation
=============

Full documentation is available at http://django-entity-event.readthedocs.org

License
=======
MIT License (see LICENSE)
